#!/usr/bin/env python3
# -*- coding: utf-8 -*-


from airflow.models import DAG

from airflow.operators.python_operator import PythonOperator
from airflow.contrib.operators.bigquery_get_data import BigQueryGetDataOperator

import pendulum
from datetime import timedelta, datetime

# time zone을 한국 시간으로 설정하려면 pendulum 등의 library를 이용한다.
local_tz = pendulum.timezone("Asia/Seoul")

"""
bq_getdata_operator.py는 처음에는 BigQueryGetDataOperator를 사용하여 BQ 테이블로부터 데이터를 취득하고 다음으로 PythonOperator에 의해 그 데이터를 취득해 표시하는 DAG다.
"""

# DAG 객체에서 이용하는 공통된 인수를 정의한다.
default_args = {
    'owner': 'Airflow',
    'start_date': datetime(2019, 1, 1, tzinfo=pendulum.timezone('Asia/Seoul')),
    'depends_on_past': True,
    'retries': 1,
    'retry_delay': timedelta(minutes=5),
}

# DAG 객체를 정의한다.
# 여기서는 정기 실행의 정의(schedule_interval)를 '1회만'으로 하고 있다.
dag = DAG(
    dag_id='bq_getdata',
    default_args=default_args,
    schedule_interval='@once',
)


bq_getdata = BigQueryGetDataOperator(
    task_id='get_data_from_bq',
    dataset_id='import',
    table_id='sales',
    max_results='1',
    selected_fields='sales_datetime',
    bigquery_conn_id='google_cloud_default',
    dag=dag,
)


def process_data_from_bq(**kwargs):
    ti = kwargs['ti']
    bq_data = ti.xcom_pull(task_ids='get_data_from_bq')
    # bq_data에, Python의 list로 데이터가 건네지고 있다.
    print(bq_data)


process_data = PythonOperator(
    task_id='process_data_from_bq',
    python_callable=process_data_from_bq,
    provide_context=True,
    dag=dag,
)

bq_getdata >> process_data