#!/usr/bin/env python3
# -*- coding: utf-8 -*-

from airflow.models import DAG

from airflow.contrib.operators.bigquery_operator import BigQueryOperator

import pendulum
from datetime import timedelta, datetime

# time zone을 한국 시간으로 설정하려면 pendulum 등의 library를 이용한다.
local_tz = pendulum.timezone("Asia/Seoul")

"""
bq_operator.py는 지정한 테이블로 Query 결과를 destination_dataset_table에 저장하는 DAG다.
"""

# DAG 객체에서 이용하는 공통된 인수를 정의한다.
default_args = {
    'owner': 'Airflow',
    'start_date': datetime(2019, 1, 1, tzinfo=pendulum.timezone('Asia/Seoul')),
    'depends_on_past': True,
    'retries': 1,
    'retry_delay': timedelta(minutes=5),
}

# DAG 객체를 정의한다.
# 여기서는 정기 실행의 정의(schedule_interval)를 '1회만'으로 하고 있다.
dag = DAG(
    dag_id='bq_operator',
    default_args=default_args,
    schedule_interval='@once',
)

# 필요한 파라미터를 지정한다.
# destination_dataset_table에 Query결과가 보관된다.
# 파라미터의 자세한 설명은 여기에；https://airflow.readthedocs.io/en/1.10.2/integration.html#bigqueryoperator
query_table = BigQueryOperator(
    task_id='query_table',
    sql='SELECT sales_number,sales_amount FROM import.sales',
    destination_dataset_table='shuwa-gcp-book.composer.bq_operator',
    create_disposition='CREATE_IF_NEEDED',
    write_disposition='WRITE_TRUNCATE',
    use_legacy_sql=False,
    dag=dag
)
query_table