#!/usr/bin/env python3
# -*- coding: utf-8 -*-

from airflow.models import DAG

from airflow.operators.bash_operator import BashOperator
from airflow.contrib.sensors.gcs_sensor import GoogleCloudStoragePrefixSensor

import pendulum
from datetime import timedelta, datetime

# time zone을 한국 시간으로 설정하려면 pendulum 등의 library를 이용한다.
local_tz = pendulum.timezone("Asia/Seoul")

"""
gcs_prefix_sensor.py는 처음에 지정한 접두사를 갖는 파일 등의 객체를 감지하고 그것이 성공하면 BashOperator를 사용하여 성공했음을 표시하는 DAG다.
"""

# DAG 객체에서 이용하는 공통된 인수를 정의한다.
default_args = {
    'owner': 'Airflow',
    'start_date': datetime(2019, 1, 1, tzinfo=pendulum.timezone('Asia/Seoul')),
    'depends_on_past': True,
    'retries': 1,
    'retry_delay': timedelta(minutes=5),
}

# DAG 객체를 정의한다.
# 여기서는 정기 실행의 정의(schedule_interval)를 '1회만'으로 하고 있다.
dag = DAG(
    dag_id='gcs_prefix_sensor',
    default_args=default_args,
    schedule_interval='@once',
)

# 버킷 바로 아래 파일을 감지한다.
sense_file = GoogleCloudStoragePrefixSensor(
    task_id='sense_file',
    bucket='composer_source',
    prefix='table_',
    timeout=60 * 60 * 24,
    dag=dag,
)

# 우선은 BashOperator를 사용하여 현재 시각을 표시한다.
operator_1 = BashOperator(
    task_id='operator_1',
    bash_command='echo "sensed the table_*.csv file"',
    dag=dag,
)

sense_file >> operator_1