#!/usr/bin/env python3
# -*- coding: utf-8 -*-

from airflow.models import DAG

from airflow.contrib.operators.gcs_to_gcs import GoogleCloudStorageToGoogleCloudStorageOperator

import pendulum
from datetime import timedelta, datetime

# time zone을 한국 시간으로 설정하려면 pendulum 등의 library를 이용한다.
local_tz = pendulum.timezone("Asia/Seoul")

"""
gcs_to_gcs_operator.py는 GCS에서 지정한 버킷 내에 존재하는 파일 객체를 별도 버킷이나 동일 버킷의 다른 폴더로 이동하는 DAG다.
"""

# DAG 객체에서 이용하는 공통된 인수를 정의한다.
default_args = {
    'owner': 'Airflow',
    'start_date': datetime(2019, 1, 1, tzinfo=pendulum.timezone('Asia/Seoul')),
    'depends_on_past': True,
    'retries': 1,
    'retry_delay': timedelta(minutes=5),
}

# DAG 객체를 정의한다.
# 여기서는 정기 실행의 정의(schedule_interval)를 '1회만'으로 하고 있다.
dag = DAG(
    dag_id='gcs_to_gcs_operator',
    default_args=default_args,
    schedule_interval='@once',
)


# GCS의 지정한 버킷에 있는 CSV파일을 별도의 버킷으로 이동한다.
# 파라미터의 자세한 내용은 여기를；https://airflow.readthedocs.io/en/1.10.2/integration.html#googlecloudstoragetogooglecloudstorageoperator
gcs_to_gcs = GoogleCloudStorageToGoogleCloudStorageOperator(
    task_id='gcs_to_gcs',
    source_bucket='composer_source',
    source_object='table_1_123456789.csv',
    destination_bucket='composer_destination',
    destination_object='table_1.csv',
    move_object=True,
    dag=dag
)

gcs_to_gcs